@@ -39,7 +39,7 @@ try:
 except ImportError:
     pass
 
-__version__ = "1.0.10"
+__version__ = "1.0.12"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_TLA202x.git"
 
 _TLA_DEFAULT_ADDRESS = const(0x48)
@@ -65,7 +65,7 @@ class CV:
             cls.lsb[value] = lsb
 
     @classmethod
-    def is_valid(cls, value: str) -> bool:
+    def is_valid(cls, value: int) -> bool:
         "Returns true if the given value is a member of the CV"
         return value in cls.string
 
